/* BdfServer - Copyright (c) 2011-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.users;

import fr.exemole.bdfserver.api.users.BdfUserPrefs;
import java.util.List;
import java.util.Locale;
import net.fichotheque.utils.SelectionUtils;
import net.mapeadores.util.attr.Attribute;
import net.mapeadores.util.attr.AttributeKey;
import net.mapeadores.util.attr.Attributes;
import net.mapeadores.util.attr.AttributesBuilder;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.localisation.Langs;
import net.mapeadores.util.localisation.LangsUtils;
import net.mapeadores.util.text.CleanedString;
import net.fichotheque.selection.FicheQuery;


/**
 *
 * @author Vincent Calame
 */
public class BdfUserPrefsBuilder {

    private final AttributesBuilder attributesBuilder;
    private Lang workingLang;
    private Locale customFormatLocale;
    private Langs customPreferenceLangs = LangsUtils.EMPTY_LANGS;
    private FicheQuery defaultFicheQuery;
    private String defaultSortType;


    public BdfUserPrefsBuilder() {
        this.attributesBuilder = new AttributesBuilder();
    }

    public void setWorkingLang(Lang workingLang) {
        this.workingLang = workingLang;
    }

    public void setCustomFormatLocale(Locale customFormatLocale) {
        this.customFormatLocale = customFormatLocale;
    }

    public void setCustomPreferenceLangs(Langs customPreferenceLangs) {
        if (customPreferenceLangs == null) {
            this.customPreferenceLangs = LangsUtils.EMPTY_LANGS;
        } else {
            this.customPreferenceLangs = customPreferenceLangs;
        }
    }

    public void setDefaultFicheQuery(FicheQuery defaultFicheQuery) {
        this.defaultFicheQuery = defaultFicheQuery;
    }

    public void setDefaultSortType(String defaultSortType) {
        this.defaultSortType = SelectionUtils.checkSortType(defaultSortType);
    }

    public void addAttribute(AttributeKey attributeKey, List<CleanedString> valueList) {
        attributesBuilder.appendValues(attributeKey, valueList);
    }

    public void addAttribute(Attribute attribute) {
        attributesBuilder.appendValues(attribute);
    }

    public BdfUserPrefs toBdfUserPrefs() {
        return new InternalBdfUserPrefs(workingLang, customFormatLocale, customPreferenceLangs, attributesBuilder.toAttributes(), defaultFicheQuery, defaultSortType);
    }


    private static class InternalBdfUserPrefs implements BdfUserPrefs {

        private final Lang workingLang;
        private final Locale customFormatLocale;
        private final Langs customPreferenceLangs;
        private final Attributes attributes;
        private final FicheQuery defaultFicheQuery;
        private final String defaultSortType;


        private InternalBdfUserPrefs(Lang workingLang, Locale customFormatLocale, Langs customPreferenceLangs,
                Attributes attributes, FicheQuery defaultFicheQuery, String defaultSortType) {
            this.workingLang = workingLang;
            this.customFormatLocale = customFormatLocale;
            this.customPreferenceLangs = customPreferenceLangs;
            this.attributes = attributes;
            this.defaultFicheQuery = defaultFicheQuery;
            this.defaultSortType = defaultSortType;
        }

        @Override
        public Lang getWorkingLang() {
            return workingLang;
        }

        @Override
        public Locale getCustomFormatLocale() {
            return customFormatLocale;
        }

        @Override
        public Langs getCustomPreferenceLangs() {
            return customPreferenceLangs;
        }

        @Override
        public FicheQuery getDefaultFicheQuery() {
            return defaultFicheQuery;
        }

        @Override
        public String getDefaultSortType() {
            return defaultSortType;
        }

        @Override
        public Attributes getAttributes() {
            return attributes;
        }

    }

}
