/* BdfServer_Commands - Copyright (c) 2012-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.administration;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.BdfServerEditor;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.managers.PermissionManager;
import fr.exemole.bdfserver.api.roles.Role;
import fr.exemole.bdfserver.api.roles.RoleEditor;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import fr.exemole.bdfserver.tools.roles.RoleUtils;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class RoleRemoveCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "RoleRemove";
    public final static String COMMANDKEY = "_ ROL-03";
    private Role role;

    public RoleRemoveCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() {
        String roleName = role.getName();
        BdfServerEditor bdfServerEditor = bdfServer.getBdfServerEditor();
        RoleEditor roleEditor = bdfServerEditor.getRoleEditor();
        roleEditor.removeRole(role);
        bdfServerEditor.saveChanges();
        setDone("_ done.administration.roleremove", roleName);
        putResultObject(STRING_OBJ, roleName);
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        checkFichothequeAdmin();
        PermissionManager permissionManager = bdfServer.getPermissionManager();
        role = BdfInstructionUtils.getMandatoryRole(permissionManager, requestMap);
        if (RoleUtils.isDefaultRole(role)) {
            throw new BdfInstructionException(BdfInstructionUtils.wrongParameterValue("role", "default role"));
        }
        if (!checkConfirmation()) {
            setError("_ error.empty.confirmationcheck_remove");
            return false;
        }
        return true;
    }

}
