/* BdfServer_Commands - Copyright (c) 2011-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.corpus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import net.fichotheque.NoRemoveableSubsetException;
import net.fichotheque.SubsetKey;
import net.fichotheque.corpus.Corpus;
import net.mapeadores.util.exceptions.ShouldNotOccurException;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class CorpusRemoveCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "CorpusRemove";
    public final static String COMMANDKEY = "_ CRP-09";
    private Corpus corpus;

    public CorpusRemoveCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() {
        initEditSession(Domains.CORPUS + "/" + COMMANDNAME);
        SubsetKey corpusKey = corpus.getSubsetKey();
        try {
            editSession.getFichothequeEditor().removeCorpus(corpus);
            setDone("_ done.corpus.corpusremove", corpusKey.getSubsetName());
            putResultObject(SUBSETKEY_OBJ, corpusKey);
        } catch (NoRemoveableSubsetException nrse) {
            throw new ShouldNotOccurException("test done before");
        }
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        checkFichothequeAdmin();
        corpus = getMandatoryCorpus();
        if (!checkConfirmation()) {
            setError("_ error.empty.confirmationcheck_remove");
            return false;
        }
        if (!fichotheque.isRemoveable(corpus)) {
            setError("_ error.notremoveable.corpus");
            return false;
        }
        return true;
    }

}
