/* BdfServer_Commands - Copyright (c) 2011-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.selection;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.interaction.FicheQueryParser;
import net.fichotheque.utils.SelectionUtils;
import net.mapeadores.util.request.RequestMap;
import net.fichotheque.selection.FicheQuery;
import net.fichotheque.corpus.SortConstants;


/**
 *
 * @author Vincent Calame
 */
public class SelectionChangeCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "SelectionChange";
    public final static String SORTTYPE_PARAMNAME = "sorttype";
    private String sortType;
    private FicheQuery ficheQuery;

    public SelectionChangeCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return false;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        bdfServer.setFicheSelection(bdfUser, ficheQuery, sortType);
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        String sorttypeParamValue = requestMap.getParameter(SORTTYPE_PARAMNAME);
        if (sorttypeParamValue != null) {
            sortType = SelectionUtils.checkSortType(sorttypeParamValue);
        } else {
            sortType = SortConstants.ID_ASC;
        }
        ficheQuery = FicheQueryParser.parse(requestMap, bdfServer, bdfUser);
        return true;
    }

}
