/* BdfServer_Commands - Copyright (c) 2013-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.thesaurus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import net.fichotheque.FichothequeEditor;
import net.fichotheque.thesaurus.Thesaurus;
import net.fichotheque.thesaurus.metadata.ThesaurusMetadata;
import net.mapeadores.util.attr.AttributeParser;
import net.fichotheque.utils.FichothequeUtils;
import net.mapeadores.util.attr.AttributeChange;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class ThesaurusAttributeChangeCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "ThesaurusAttributeChange";
    public final static String COMMANDKEY = "_ THS-19";
    public final static String ATTRIBUTES_PARAMNAME = "attributes";
    private Thesaurus thesaurus;
    private AttributeChange attributeChange;

    public ThesaurusAttributeChangeCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.THESAURUS + "/" + COMMANDNAME);
        FichothequeEditor fichothequeEditor = editSession.getFichothequeEditor();
        ThesaurusMetadata metadata = thesaurus.getThesaurusMetadata();
        FichothequeUtils.changeAttributes(fichothequeEditor, metadata, attributeChange);
        putResultObject(THESAURUS_OBJ, thesaurus);
        setDone("_ done.global.attributechange");
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        thesaurus = getMandatoryThesaurus();
        checkSubsetAdmin(thesaurus);
        String attributes = getMandatory(ATTRIBUTES_PARAMNAME);
        this.attributeChange = AttributeParser.parse(attributes);
        return true;
    }

}
