/* BdfServer_HtmlProducers - Copyright (c) 2011-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.selection;

import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.api.interaction.domains.MainDomain;
import fr.exemole.bdfserver.api.interaction.domains.SelectionDomain;
import fr.exemole.bdfserver.api.roles.PermissionSummary;
import fr.exemole.bdfserver.commands.selection.SelectionChangeCommand;
import fr.exemole.bdfserver.commands.selection.SelectionDefaultCommand;
import fr.exemole.bdfserver.html.BdfHtmlConstants;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import fr.exemole.bdfserver.html.ParameterMap;
import fr.exemole.bdfserver.html.consumers.Button;
import fr.exemole.bdfserver.html.consumers.PageUnit;
import fr.exemole.bdfserver.html.consumers.SelectOption;
import fr.exemole.bdfserver.html.forms.SelectionFormPrinter;
import fr.exemole.bdfserver.html.jslib.CommonJsLibs;
import fr.exemole.bdfserver.tools.BH;
import net.fichotheque.corpus.SortConstants;
import net.fichotheque.selection.FicheQuery;
import net.mapeadores.util.html.HA;
import net.mapeadores.util.request.RequestConstants;
import fr.exemole.bdfserver.api.instruction.BdfParameters;


/**
 *
 * @author Vincent Calame
 */
public class SelectionFormHtmlProducer extends BdfServerHtmlProducer {

    public final static String BEFORE_INSERT = "before";
    public final static String AFTER_INSERT = "after";
    private final static SelectOption[] SORTTYPE_OPTIONS = {
        SelectOption.init(SortConstants.TITRE_ASC).textLocKey("_ label.selection.sorttype_titre"),
        SelectOption.init(SortConstants.ID_ASC).textLocKey("_ label.selection.sorttype_id"),
        SelectOption.init(SortConstants.CREATIONDATE_DESC).textLocKey("_ label.selection.sorttype_creationdate"),
        SelectOption.init(SortConstants.MODIFICATIONDATE_DESC).textLocKey("_ label.selection.sorttype_modificationdate")
    };
    private final PermissionSummary permissionSummary;
    private FicheQuery ficheQuery;

    public SelectionFormHtmlProducer(BdfParameters bdfParameters, String selectionName) {
        super(bdfParameters);
        this.permissionSummary = bdfParameters.getPermissionSummary();
        addJsLib(CommonJsLibs.SELECTFORM);
        addThemeCss("selectform.css", "selection.css");
        initFicheQuery(selectionName);
        initHook(SelectionFormHtmlProducer.class);
    }

    private void initFicheQuery(String selectionName) {
        if (selectionName != null) {
            if (selectionName.equals("_default")) {
                ficheQuery = bdfUser.getPrefs().getDefaultFicheQuery();
            }
        }
        if (ficheQuery == null) {
            ficheQuery = bdfUser.getFicheQuery();
        }
    }

    @Override
    public void printHtml() {
        start();
        printToolBarLinks();
        insertInclude(BEFORE_INSERT);
        printStandardUnit();
        insertInclude(AFTER_INSERT);
        end();
    }

    public FicheQuery getFicheQuery() {
        return ficheQuery;
    }

    protected void printToolBarLinks() {
        this
                .DIV("global-PageToolbar")
                .__(printPageLink("action-defaultselection-Save", "_ link.selection.default_save", RequestConstants.COMMAND_PARAMETER, SelectionDefaultCommand.COMMANDNAME))
                .__space()
                .__(printPageLink("action-defaultselection-Load", "_ link.selection.default_load", SelectionDomain.SELECTIONNAME_PARAMNAME, "_default"))
                ._DIV();
    }

    private void printStandardUnit() {
        this
                .__(PageUnit.start("action-Selection", "_ title.selection.fichesselection").sectionCss("unit-Unit selection-Unit"))
                .FORM_get(Domains.SELECTION, BdfHtmlConstants.LIST_FRAME)
                .INPUT_hidden(ParameterMap.init()
                        .command(SelectionChangeCommand.COMMANDNAME)
                        .page(Domains.MAIN, MainDomain.FICHES_PAGE));
        this
                .P("selection-Submit")
                .__(printHtmlSelectSortType())
                .__space()
                .__(Button.submit("_ submit.selection.selectionchange"))
                ._P();
        this
                .__(SelectionFormPrinter.init(getFicheQuery(), bdfServer, bdfUser, permissionSummary, this)
                        .printFieldsets()
                )
                .__(SelectionFormPrinter.printSeparator(this));
        this
                ._FORM()
                .__(PageUnit.END);
    }

    private boolean printPageLink(String actionClass, String titleLocKey, String extraParamName, String extraParamValue) {
        this
                .A(HA.href(BH.domain(Domains.SELECTION).page(SelectionDomain.SELECTIONFORM_PAGE).param(extraParamName, extraParamValue)).classes("global-button-Transparent global-button-Transparent32").addClass(actionClass).titleLocKey(titleLocKey))
                .__(Button.ICON)
                ._A();
        return true;
    }

    protected boolean printHtmlSelectSortType() {
        String sortType = bdfUser.getSortType();
        this
                .__localize("_ label.selection.sorttype")
                .__colon()
                .SELECT(SelectionChangeCommand.SORTTYPE_PARAMNAME);
        for (SelectOption option : SORTTYPE_OPTIONS) {
            this
                    .__(option, sortType);
        }
        this
                ._SELECT();
        return true;
    }

}
