/* BdfServer_JsonProducers - Copyright (c) 2012-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.jsonproducers.configuration;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfCommandResult;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.instruction.OutputParameters;
import fr.exemole.bdfserver.api.interaction.domains.ConfigurationDomain;
import fr.exemole.bdfserver.jsonproducers.ResultJsonProducer;
import fr.exemole.bdfserver.tools.configuration.PathConfigurationBuilder;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import java.util.LinkedHashSet;
import java.util.Set;
import net.fichotheque.SubsetKey;
import net.mapeadores.util.json.JsonProducer;
import net.mapeadores.util.localisation.MessageLocalisation;
import net.mapeadores.util.request.RequestMap;
import net.mapeadores.util.text.StringUtils;


/**
 *
 * @author Vincent Calame
 */
public final class ConfigurationJsonProducerFactory {

    private ConfigurationJsonProducerFactory() {
    }

    public static JsonProducer getJsonProducer(OutputParameters parameters) throws BdfInstructionException {
        String json = parameters.getOutput();
        BdfCommandResult bdfCommandResult = parameters.getBdfCommandResult();
        BdfServer bdfServer = parameters.getBdfServer();
        RequestMap requestMap = parameters.getRequestMap();
        MessageLocalisation messageLocalisation = parameters.getMessageLocalisation();
        ResultJsonProducer jsonProducer = new ResultJsonProducer(bdfCommandResult, messageLocalisation);
        switch (json) {
            case ConfigurationDomain.SUBSETTREEMAP_JSON: {
                boolean withDetails = requestMap.isTrue(ConfigurationDomain.WITHDETAILS_PARAMNAME);
                jsonProducer.add(new SubsetTreeMapJsonProperty(bdfServer, parameters.getWorkingLang(), getCategoryArray(requestMap), withDetails));
                return jsonProducer;
            }
            case ConfigurationDomain.LANGCONFIGURATION_JSON: {
                jsonProducer.add(new LangConfigurationJsonProperty(bdfServer));
                return jsonProducer;
            }
            case ConfigurationDomain.PATHCONFIGURATION_JSON: {
                jsonProducer.add(new PathConfigurationJsonProperty(PathConfigurationBuilder.build(bdfServer)));
                return jsonProducer;
            }
            default:
                return null;
        }
    }

    private static short[] getCategoryArray(RequestMap requestMap) throws BdfInstructionException {
        String[] categoriesArray = BdfInstructionUtils.getMandatoryParameterValues(requestMap, "categories");
        Set<Short> categorySet = new LinkedHashSet<Short>();
        int categoriesLength = categoriesArray.length;
        for (int j = 0; j < categoriesLength; j++) {
            String[] tokensArray = StringUtils.getTechnicalTokens(categoriesArray[j], true);
            int length = tokensArray.length;
            for (int i = 0; i < length; i++) {
                try {
                    categorySet.add(SubsetKey.categoryToShort(tokensArray[i]));
                } catch (IllegalArgumentException iae) {
                    throw new BdfInstructionException(BdfInstructionUtils.unknownParameterValue("categories", tokensArray[i]));
                }
            }
        }
        short[] result = new short[categorySet.size()];
        int p = 0;
        for (Short sh : categorySet) {
            result[p] = sh;
            p++;
        }
        return result;
    }

}
