/* BdfServer_JsonProducers - Copyright (c) 2010-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.jsonproducers.pioche;

import java.io.IOException;
import java.util.Collection;
import net.fichotheque.exportation.table.Cell;
import net.fichotheque.exportation.table.CellEngine;
import net.fichotheque.json.CellJson;
import net.fichotheque.thesaurus.Motcle;
import net.mapeadores.util.json.JSONWriter;
import net.mapeadores.util.json.JsonProducer;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.text.Label;
import net.mapeadores.util.text.LabelUtils;


/**
 *
 * @author Vincent Calame
 */
public class MotcleArrayJsonProducer implements JsonProducer {

    private final Lang workingLang;
    private final Collection<Motcle> motscles;
    private final CellEngine cellEngine;


    public MotcleArrayJsonProducer(Lang workingLang, Collection<Motcle> motscles, CellEngine cellEngine) {
        this.workingLang = workingLang;
        this.motscles = motscles;
        this.cellEngine = cellEngine;
    }


    @Override
    public void writeJson(Appendable appendable) throws IOException {
        JSONWriter jw = new JSONWriter(appendable);
        jw.object();
        {
            jw.key("length")
                    .value(motscles.size());
            jw.key("array");
            jw.array();
            for (Motcle motcle : motscles) {
                String idalpha = motcle.getIdalpha();
                String title = "";
                Label label = LabelUtils.getLangPartCheckedLabel(motcle.getLabels(), workingLang);
                if (label != null) {
                    title = label.getLabelString();
                }
                Cell[] cellArray = cellEngine.getCellArray(motcle);
                jw.object();
                {
                    jw.key("thesaurus")
                            .value(motcle.getSubsetName());
                    jw.key("id")
                            .value(motcle.getId());
                    if (idalpha != null) {
                        jw.key("idalpha")
                                .value(idalpha);
                        jw.key("code")
                                .value(idalpha);
                    }
                    jw.key("title")
                            .value(title);
                    CellJson.cellArrayMappingProperty(jw, cellArray);
                }
                jw.endObject();
            }
            jw.endArray();
        }
        jw.endObject();
    }

}
