/* BdfServer_Multi - Copyright (c) 2018-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.multi.jsonproducers.admin;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.json.SubsetTreeJson;
import fr.exemole.bdfserver.multi.api.Multi;
import fr.exemole.bdfserver.multi.json.FichothequeJson;
import java.io.IOException;
import java.util.SortedSet;
import net.fichotheque.SubsetKey;
import net.mapeadores.util.json.JSONWriter;
import net.mapeadores.util.json.JsonProperty;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.localisation.MessageLocalisation;


/**
 *
 * @author Vincent Calame
 */
public class FichothequeArrayJsonProperty implements JsonProperty {

    private final Multi multi;
    private final MessageLocalisation messageLocalisation;
    private final Lang lang;

    public FichothequeArrayJsonProperty(Multi multi, MessageLocalisation messageLocalisation, Lang lang) {
        this.multi = multi;
        this.messageLocalisation = messageLocalisation;
        this.lang = lang;
    }

    @Override
    public void write(JSONWriter jw) throws IOException {
        SortedSet<String> set = multi.getExistingNameSet();
        jw.key("fichothequeArray");
        jw.array();
        for (String name : set) {
            boolean isInit = multi.isInit(name);
            jw.object();
            {
                jw.key("name")
                        .value(name);
                jw.key("init")
                        .value(isInit);
                if (isInit) {
                    fichothequeProperties(jw, multi.getBdfServer(name));
                } else {
                    FichothequeJson.titleProperties(jw, multi.getBdfServerDirs(name), lang);
                }
            }
            jw.endObject();
        }
        jw.endArray();
    }

    private void fichothequeProperties(JSONWriter jw, BdfServer bdfServer) throws IOException {
        FichothequeJson.titleProperties(jw, bdfServer, lang);
        SubsetTreeJson.Parameters parameters = new SubsetTreeJson.Parameters(bdfServer, lang, messageLocalisation);
        SubsetTreeJson.properties(jw, parameters, SubsetKey.CATEGORY_CORPUS);
        SubsetTreeJson.properties(jw, parameters, SubsetKey.CATEGORY_THESAURUS);
        SubsetTreeJson.properties(jw, parameters, SubsetKey.CATEGORY_SPHERE);
        SubsetTreeJson.properties(jw, parameters, SubsetKey.CATEGORY_ALBUM);
        SubsetTreeJson.properties(jw, parameters, SubsetKey.CATEGORY_ADDENDA);
    }

}
