/* FichothequeLib_API - Copyright (c) 2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.utils;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import net.fichotheque.EditOrigin;


/**
 *
 * @author Vincent Calame
 */
public final class EditOriginUtils {

    private final static DateFormat ISOTIME_DATEFORMAT = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'");

    private EditOriginUtils() {

    }

    public static EditOrigin newEditOrigin(String source) {
        String isoTime;
        synchronized (ISOTIME_DATEFORMAT) {
            isoTime = ISOTIME_DATEFORMAT.format(new Date());
        }
        return new InternalEditOrigin(null, null, isoTime, source);
    }

    public static EditOrigin newEditOrigin(String sessionId, String redacteurGlobalId, String source) {
        String isoTime;
        synchronized (ISOTIME_DATEFORMAT) {
            isoTime = ISOTIME_DATEFORMAT.format(new Date());
        }
        return new InternalEditOrigin(sessionId, redacteurGlobalId, isoTime, source);
    }


    private static class InternalEditOrigin implements EditOrigin {

        private final String redacteurGlobalId;
        private final String isoTime;
        private final String source;
        private final String sessionId;

        private InternalEditOrigin(String sessionId, String redacteurGlobalId, String isoTime, String source) {
            this.sessionId = sessionId;
            this.redacteurGlobalId = redacteurGlobalId;
            this.isoTime = isoTime;
            this.source = source;
        }

        @Override
        public String getSessionId() {
            return sessionId;
        }

        @Override
        public String getRedacteurGlobalId() {
            return redacteurGlobalId;
        }

        @Override
        public String getISOTime() {
            return isoTime;
        }

        @Override
        public String getSource() {
            return source;
        }

    }


}
