/* FichothequeLib_Tools - Copyright (c) 2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.corpus;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import net.fichotheque.corpus.Corpus;
import net.fichotheque.corpus.fiche.Fiche;
import net.fichotheque.corpus.fiche.Information;
import net.fichotheque.corpus.fiche.Propriete;
import net.fichotheque.corpus.fiche.Section;
import net.fichotheque.corpus.metadata.CorpusField;
import net.fichotheque.corpus.metadata.CorpusMetadata;
import net.fichotheque.corpus.metadata.FieldKey;


/**
 *
 * @author Vincent Calame
 */
public final class PurgeEngine {

    private final Set<FieldKey> currentSet;
    private final boolean soustitrePurge;

    private PurgeEngine(Set<FieldKey> currentSet, boolean soustitrePurge) {
        this.currentSet = currentSet;
        this.soustitrePurge = soustitrePurge;
    }

    public void purge(Fiche fiche) {
        if (soustitrePurge) {
            fiche.setSoustitre(null);
        }
        purgeProprieteList(fiche);
        purgeInformationList(fiche);
        purgeSectionList(fiche);
    }

    private void purgeProprieteList(Fiche fiche) {
        List<FieldKey> purgeList = new ArrayList<FieldKey>();
        for (Propriete propriete : fiche.getProprieteList()) {
            FieldKey fieldKey = propriete.getFieldKey();
            if (!currentSet.contains(fieldKey)) {
                purgeList.add(fieldKey);
            }
        }
        if (!purgeList.isEmpty()) {
            for (FieldKey fieldKey : purgeList) {
                fiche.setPropriete(fieldKey, null);
            }
        }
    }

    private void purgeInformationList(Fiche fiche) {
        List<FieldKey> purgeList = new ArrayList<FieldKey>();
        for (Information information : fiche.getInformationList()) {
            FieldKey fieldKey = information.getFieldKey();
            if (!currentSet.contains(fieldKey)) {
                purgeList.add(fieldKey);
            }
        }
        if (!purgeList.isEmpty()) {
            for (FieldKey fieldKey : purgeList) {
                fiche.setInformation(fieldKey, null);
            }
        }
    }

    private void purgeSectionList(Fiche fiche) {
        List<FieldKey> purgeList = new ArrayList<FieldKey>();
        for (Section section : fiche.getSectionList()) {
            FieldKey fieldKey = section.getFieldKey();
            if (!currentSet.contains(fieldKey)) {
                purgeList.add(fieldKey);
            }
        }
        if (!purgeList.isEmpty()) {
            for (FieldKey fieldKey : purgeList) {
                fiche.setSection(fieldKey, null);
            }
        }
    }

    public static PurgeEngine build(Corpus corpus) {
        Set<FieldKey> currentSet = new HashSet<FieldKey>();
        CorpusMetadata corpusMetadata = corpus.getCorpusMetadata();
        for (CorpusField corpusField : corpusMetadata.getProprieteList()) {
            currentSet.add(corpusField.getFieldKey());
        }
        for (CorpusField corpusField : corpusMetadata.getInformationList()) {
            currentSet.add(corpusField.getFieldKey());
        }
        for (CorpusField corpusField : corpusMetadata.getSectionList()) {
            currentSet.add(corpusField.getFieldKey());
        }
        boolean soustitrePurge = false;
        if (!corpusMetadata.isWithSoustitre()) {
            soustitrePurge = true;
        }
        return new PurgeEngine(currentSet, soustitrePurge);
    }

}
