/* FichothequeLib_Xml - Copyright (c) 2011-2017 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.xml.extraction;

import java.io.IOException;
import net.fichotheque.addenda.Addenda;
import net.fichotheque.extraction.ExtractionContext;
import net.fichotheque.extraction.def.ExtraitAddendaDef;
import net.fichotheque.extraction.run.DocumentExtractInfo;
import net.fichotheque.extraction.run.ExtraitAddendaResult;
import net.mapeadores.util.xml.XMLPart;
import net.mapeadores.util.xml.XMLWriter;


/**
 *
 * @author Vincent Calame
 */
public class ExtraitAddendaXMLPart extends XMLPart {

    private final ExtractionContext extractionContext;
    private final DocumentXMLPart documentXMLPart;

    public ExtraitAddendaXMLPart(XMLWriter xmlWriter, ExtractionContext extractionContext) {
        super(xmlWriter);
        this.extractionContext = extractionContext;
        documentXMLPart = new DocumentXMLPart(xmlWriter, extractionContext);
    }

    public void addExtraitAddenda(ExtraitAddendaResult extraitAddendaResult) throws IOException {
        ExtraitAddendaDef extraitAddendaDef = extraitAddendaResult.getExtraitAddendaDef();
        String tagName = extraitAddendaDef.getTagName();
        boolean withTag = (tagName != null);
        int addendaCount = extraitAddendaResult.getAddendaCount();
        String extraitName = extraitAddendaDef.getExtraitName();
        if (extraitName != null) {
            if (withTag) {
                startOpenTag(tagName);
                addAttribute("extrait-name", extraitName);
                endOpenTag();
            }
            for (int j = 0; j < addendaCount; j++) {
                for (DocumentExtractInfo documentExtractInfo : extraitAddendaResult.getDocumentExtractInfoList(j)) {
                    documentXMLPart.addDocument(documentExtractInfo);
                }
            }
            if (withTag) {
                closeTag(tagName);
            }
        } else {
            for (int j = 0; j < addendaCount; j++) {
                Addenda thesaurus = extraitAddendaResult.getAddenda(j);
                if (withTag) {
                    startOpenTag(tagName);
                    addAttribute("addenda", thesaurus.getSubsetName());
                    endOpenTag();
                }
                for (DocumentExtractInfo documentExtractInfo : extraitAddendaResult.getDocumentExtractInfoList(j)) {
                    documentXMLPart.addDocument(documentExtractInfo);
                }
                if (withTag) {
                    closeTag(tagName);
                }
            }
        }
    }

}
